@@ -10,7 +10,7 @@ except ImportError:
 else:
     from .qimageview import qimageview as _qimageview
 
-__version__ = "1.2"
+__version__ = "1.3"
 
 if _sys.byteorder == 'little':
     _bgra = (0, 1, 2, 3)
@@ -26,6 +26,17 @@ bgra_dtype = _np.dtype(_bgra_fields)
 """Complex dtype offering the named fields 'r','g','b', and 'a' and
 corresponding long names, conforming to QImage_'s 32-bit memory layout."""
 
+try:
+    _basestring = basestring
+except NameError:
+    # 'basestring' undefined, must be Python 3
+    _basestring = str
+
+def _qimage_or_filename_view(qimage):
+    if isinstance(qimage, _basestring):
+        qimage = _qt.QImage(qimage)
+    return _qimageview(qimage)
+
 def raw_view(qimage):
     """Returns raw 2D view of the given QImage_'s memory.  The result
     will be a 2-dimensional numpy.ndarray with an appropriately sized
@@ -36,7 +47,8 @@ def raw_view(qimage):
     :param qimage: image whose memory shall be accessed via NumPy
     :type qimage: QImage_
     :rtype: numpy.ndarray_ with shape (height, width)"""
-    return _qimageview(qimage)
+    return _qimage_or_filename_view(qimage)
+
 
 def byte_view(qimage, byteorder = 'little'):
     """Returns raw 3D view of the given QImage_'s memory.  This will
@@ -55,16 +67,20 @@ def byte_view(qimage, byteorder = 'little'):
     sys.byteorder here, i.e. return native order for the machine the
     code is running on.
 
+    For your convenience, `qimage` may also be a filename, see
+    `Loading Images`_ in the documentation.
+
     :param qimage: image whose memory shall be accessed via NumPy
     :type qimage: QImage_
     :param byteorder: specify order of channels in last axis
     :rtype: numpy.ndarray_ with shape (height, width, 1 or 4) and dtype uint8"""
-    raw = _qimageview(qimage)
+    raw = _qimage_or_filename_view(qimage)
     result = raw.view(_np.uint8).reshape(raw.shape + (-1, ))
     if byteorder and byteorder != _sys.byteorder:
         result = result[...,::-1]
     return result
 
+
 def rgb_view(qimage, byteorder = 'big'):
     """Returns RGB view of a given 32-bit color QImage_'s memory.
     Similarly to byte_view(), the result is a 3D numpy.uint8 array,
@@ -80,6 +96,9 @@ def rgb_view(qimage, byteorder = 'big'):
     sys.byteorder here, i.e. return native order for the machine the
     code is running on.
 
+    For your convenience, `qimage` may also be a filename, see
+    `Loading Images`_ in the documentation.
+
     :param qimage: image whose memory shall be accessed via NumPy
     :type qimage: QImage_ with 32-bit pixel type
     :param byteorder: specify order of channels in last axis
@@ -95,6 +114,7 @@ def rgb_view(qimage, byteorder = 'big'):
     else:
         return bytes[...,1:] # strip A off ARGB
 
+
 def alpha_view(qimage):
     """Returns alpha view of a given 32-bit color QImage_'s memory.
     The result is a 2D numpy.uint8 array, equivalent to
@@ -104,6 +124,9 @@ def alpha_view(qimage):
     *uses* the alpha channel -- for Format_RGB32, the alpha channel
     usually contains 255 everywhere.
 
+    For your convenience, `qimage` may also be a filename, see
+    `Loading Images`_ in the documentation.
+
     :param qimage: image whose memory shall be accessed via NumPy
     :type qimage: QImage_ with 32-bit pixel type
     :rtype: numpy.ndarray_ with shape (height, width) and dtype uint8"""
@@ -112,6 +135,7 @@ def alpha_view(qimage):
         raise ValueError("For alpha_view, the image must have 32 bit pixel size (use RGB32, ARGB32, or ARGB32_Premultiplied)")
     return bytes[...,_bgra[3]]
 
+
 def recarray_view(qimage):
     """Returns recarray_ view of a given 32-bit color QImage_'s
     memory.
@@ -121,6 +145,9 @@ def recarray_view(qimage):
     Thus, each color components can be accessed either via string
     indexing or via attribute lookup (through numpy.recarray_):
 
+    For your convenience, `qimage` may also be a filename, see
+    `Loading Images`_ in the documentation.
+
     >>> from PyQt4.QtGui import QImage, qRgb
     >>> qimg = QImage(320, 240, QImage.Format_ARGB32)
     >>> qimg.fill(qRgb(12,34,56))
@@ -142,12 +169,12 @@ def recarray_view(qimage):
     :param qimage: image whose memory shall be accessed via NumPy
     :type qimage: QImage_ with 32-bit pixel type
     :rtype: numpy.ndarray_ with shape (height, width) and dtype :data:`bgra_dtype`"""
-    raw = _qimageview(qimage)
+    raw = _qimage_or_filename_view(qimage)
     if raw.itemsize != 4:
         raise ValueError("For rgb_view, the image must have 32 bit pixel size (use RGB32, ARGB32, or ARGB32_Premultiplied)")
     return raw.view(bgra_dtype, _np.recarray)
 
-# --------------------------------------------------------------------
+
 
 def _normalize255(array, normalize, clip = (0, 255)):
     if normalize:
@@ -174,6 +201,7 @@ def _normalize255(array, normalize, clip = (0, 255)):
 
     return array
 
+
 def gray2qimage(gray, normalize = False):
     """Convert the 2D numpy array `gray` into a 8-bit, indexed QImage_
     with a gray colormap.  The first dimension represents the vertical
@@ -231,6 +259,7 @@ def gray2qimage(gray, normalize = False):
 
     return result
 
+
 def array2qimage(array, normalize = False):
     """Convert a 2D or 3D numpy array into a 32-bit QImage_.  The
     first dimension represents the vertical image axis; the optional
@@ -306,3 +335,38 @@ def array2qimage(array, normalize = False):
         alpha[:]  *= _np.logical_not(_np.any(array.mask, axis = -1))
 
     return result
+
+
+def imread(filename):
+    """Convenience function that uses the QImage_ constructor to read an
+    image from the given file and return an `rgb_view` of the result.
+    This is intentionally similar to scipy.ndimage.imread (which uses
+    PIL), scipy.misc.imread, or matplotlib.pyplot.imread (using PIL
+    for non-PNGs).
+
+    For grayscale images, return 2D array (even if it comes from a 32-bit
+    representation; this is a consequence of the QImage API).
+
+    This function has been added in version 1.3.
+    """
+    qImage = _qt.QImage(filename)
+
+    isGray = qImage.isGrayscale()
+    if isGray and qImage.depth() == 8:
+        return byte_view(qImage)[...,0]
+
+    hasAlpha = qImage.hasAlphaChannel()
+
+    if hasAlpha:
+        targetFormat = _qt.QImage.Format_ARGB32
+    else:
+        targetFormat = _qt.QImage.Format_RGB32
+    if qImage.format() != targetFormat:
+        qImage = qImage.convertToFormat(targetFormat)
+
+    result = rgb_view(qImage)
+    if isGray:
+        result = result[...,0]
+    if hasAlpha:
+        result = _np.dstack((result, alpha_view(qImage)))
+    return result
